# mypy-boto3-cloudhsm

[![PyPI - mypy-boto3-cloudhsm](https://img.shields.io/pypi/v/mypy-boto3-cloudhsm.svg?color=blue)](https://pypi.org/project/mypy-boto3-cloudhsm)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-cloudhsm.svg?color=blue)](https://pypi.org/project/mypy-boto3-cloudhsm)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.CloudHSM 1.14.55](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/cloudhsm.html#CloudHSM) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.0.4](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-cloudhsm](#mypy-boto3-cloudhsm)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `CloudHSM` service.

```bash
python -m pip install boto3-stubs[cloudhsm]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[cloudhsm]` in your environment: `python -m pip install 'boto3-stubs[cloudhsm]'`

Both type checking and auto-complete should work for `CloudHSM` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[cloudhsm]` in your environment: `python -m pip install 'boto3-stubs[cloudhsm]'`

Both type checking and auto-complete should work for `CloudHSM` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[cloudhsm]` in your environment: `python -m pip install 'boto3-stubs[cloudhsm]'`
- Run `mypy` as usual

Type checking should work for `CloudHSM` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[cloudhsm]` in your environment: `python -m pip install 'boto3-stubs[cloudhsm]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CloudHSM` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`CloudHSMClient` provides annotations for `boto3.client("cloudhsm")`.

```python
import boto3

from mypy_boto3_cloudhsm import CloudHSMClient

client: CloudHSMClient = boto3.client("cloudhsm")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CloudHSMClient = session.client("cloudhsm")
```

### Paginators annotations

`mypy_boto3_cloudhsm.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_cloudhsm import CloudHSMClient
from mypy_boto3_cloudhsm.paginator import (
    ListHapgsPaginator,
    ListHsmsPaginator,
    ListLunaClientsPaginator,
)

client: CloudHSMClient = boto3.client("cloudhsm")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_hapgs_paginator: ListHapgsPaginator = client.get_paginator("list_hapgs")
list_hsms_paginator: ListHsmsPaginator = client.get_paginator("list_hsms")
list_luna_clients_paginator: ListLunaClientsPaginator = client.get_paginator("list_luna_clients")
```







### Typed dictionations

`mypy_boto3_cloudhsm.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_cloudhsm.type_defs import (
    AddTagsToResourceResponseTypeDef,
    CreateHapgResponseTypeDef,
    CreateHsmResponseTypeDef,
    CreateLunaClientResponseTypeDef,
    DeleteHapgResponseTypeDef,
    DeleteHsmResponseTypeDef,
    DeleteLunaClientResponseTypeDef,
    DescribeHapgResponseTypeDef,
    DescribeHsmResponseTypeDef,
    DescribeLunaClientResponseTypeDef,
    GetConfigResponseTypeDef,
    ListAvailableZonesResponseTypeDef,
    ListHapgsResponseTypeDef,
    ListHsmsResponseTypeDef,
    ListLunaClientsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ModifyHapgResponseTypeDef,
    ModifyHsmResponseTypeDef,
    ModifyLunaClientResponseTypeDef,
    PaginatorConfigTypeDef,
    RemoveTagsFromResourceResponseTypeDef,
    TagTypeDef,
)

def get_structure() -> TagTypeDef:
    return {
      ...
    }
```
